@@ -73,7 +73,7 @@ def build_js(name, events, commands, activity_bar_config=None):
     with open(os.path.join(directory, "main.js"), "r") as f:
         imports += f.read()
     on_activate = events.get("activate")
-    code_on_activate = "function activate(context) {\n"
+    code_on_activate = "function activate(context) {\nlet globalStorage = {}\n"
     if on_activate:
         r = str(on_activate()).replace('"', '\\"')
         code_on_activate += f'console.log("{r}");\n'
@@ -105,7 +105,7 @@ context.subscriptions.push(
         )
         code_on_activate += """
 py.stdout.on("data", (data) => {
-    executeCommands(py, data);
+    executeCommands(py, data, globalStorage);
 });
 py.stderr.on("data", (data) => {
     console.error(`An Error occurred in the python script: ${data}`);
@@ -167,6 +167,10 @@ def create_files(package, javascript, python, publish):
         f.write(python)
     os.chdir(cwd)
 
+    if not os.path.isfile("requirements.txt"):
+        with open("requirements.txt", "w") as f:
+            f.write("vscode-ext")
+
     if publish:
         if not os.path.isfile("README.md"):
             with open("README.md", "w") as f:
@@ -180,9 +184,6 @@ def create_files(package, javascript, python, publish):
             with open(".vscodeignore", "w") as f:
                 f.write(".vscode/**")
 
-        if not os.path.isfile("requirements.txt"):
-            with open("requirements.txt", "w") as f:
-                f.write("vscode-ext")
 
 
 def build(extension: Extension, publish:bool=False, config:dict=None) -> None:
@@ -192,9 +193,11 @@ def build(extension: Extension, publish:bool=False, config:dict=None) -> None:
     if config is None:
         config = {}
     if publish:
-        if config.get("publisher") is None:
+        if extension.publisher is None:
             config["publisher"] = input("Enter publisher name: ")
-
+        else:
+            config["publisher"] = extension.publisher 
+        
     print(f"\033[1;37;49mBuilding Extension {extension.name}...", "\033[0m")
     start = time.time()
 
